setClass("RococoTestResults",
         representation=representation(count="integer",
                                       tnorm="list",
                                       input="character",
                                       length="numeric",
                                       p.value="numeric",
                                       p.value.approx="numeric",
                                       r.values="numeric",
                                       numtests="integer",
                                       exact="logical",
                                       similarity="character",
                                       sample.gamma="numeric",
                                       H0gamma.mu="numeric",
                                       H0gamma.sd="numeric",
                                       perm.gamma="numeric",
                                       alternative="character"))
